library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;

entity vga_text is
port(
  clock : in std_logic;
  
  hsync : out std_logic;
  vsync : out std_logic;
  red   : OUT STD_LOGIC_VECTOR(3 downto 0);
  green : OUT STD_LOGIC_VECTOR(3 downto 0);
  blue  : OUT STD_LOGIC_VECTOR(3 downto 0)
  ); 
end vga_text;

architecture behavioral of vga_text is

signal offs     : unsigned (6 downto 0);
signal counterx : unsigned (9 downto 0);
signal countery : unsigned (9 downto 0);
signal basis    : unsigned (11 downto 0);
signal charlin  : unsigned (11 downto 0);
signal zpos     : unsigned (11 downto 0);
signal wr_addr  : unsigned (11 downto 0);

signal dat     : std_logic_vector (7 downto 0);
signal char    : std_logic_vector (7 downto 0);
signal dat_w   : std_logic_vector (7 downto 0);

signal counterxmaxed : std_logic;
signal counterymaxed : std_logic;
signal h_enable      : std_logic;
signal v_enable      : std_logic;
signal vid_enable    : std_logic;
signal pixel         : std_logic;
signal clk25         : std_logic;
signal we            : std_logic;

component ram port(
  clk25   : in  std_logic;
  we      : in  std_logic;
  wr_addr : in  unsigned (11 downto 0);
  rd_addr : in  unsigned (11 downto 0);
  d       : in  std_logic_vector (7 downto 0);
  q       : out std_logic_vector (7 downto 0)
  );
end component;

component rom port(
  clk25  : in  std_logic;
  addr_a : in  unsigned (11 downto 0);
  q_a    : out std_logic_vector (7 downto 0)
  );
end component;

begin
io1 : ram  port map(
 clk25   => clk25,
 we      => we,
 rd_addr => zpos,
 wr_addr => wr_addr,
 q       => char,
 d       => dat_w
);

io2 : rom  port map(
  clk25  => clk25,
  addr_a => charlin,
  q_a    => dat
);

clk25 <= not clk25 when rising_edge(clock);

process
begin
  wait until rising_edge(clk25);
    if counterxmaxed ='1' then
      counterx <= to_unsigned(0, counterx'length);
    else
      counterx <= counterx + 1; 
      if dat(to_integer(unsigned(counterx(2 downto 0)))) = '0' then
        pixel<='0';
      else
        pixel<='1';
      end if;       
    end if;
    
    if counterxmaxed ='1' then
      if counterymaxed ='1' then 
        countery <=  to_unsigned(0, countery'length);
      else  
        countery<= countery + 1;      
      end if;  
    end if ; 
      
    if counterx =0 and  countery =0 then
      basis <=to_unsigned(0, basis'length);
    elsif counterx =0 and countery(3 downto 0) =0 then 
      basis<= basis + 80; 
    end if;        
   
    offs <= counterx(9 downto 3);
    zpos <= basis + offs;
end process;

process
begin
  wait until rising_edge(clk25);
    if vid_enable ='1' and pixel='1' then
      red  <="1111";
      green<="1111";
      blue <="1111";
    else
      red  <="0000";
      green<="0000";
      blue <="0000";    
    end if;
end process;

counterxmaxed <='1' when  counterx = 800 else '0';
counterymaxed <='1' when  countery = 525 else '0';

hsync <='1' when  counterx < 659 or counterx > 751 else '0';
vsync <='1' when  countery < 489 or countery > 491 else '0';

h_enable   <= '1' when  counterx > 4 and counterx < 645 else '0';
v_enable   <= '1' when  countery < 480 else '0'; 
vid_enable <= '1' when h_enable = '1' and v_enable = '1' else '0';

charlin <=resize(unsigned(char),12)+ resize(unsigned(countery(3 downto 1)),12);

end behavioral;